from .huepy import *

__all__ = ['bad', 'bg', 'black', 'blue', 'bold', 'cyan', 'good', 'green',
           'grey', 'info', 'italic', 'lblue', 'lightblue', 'lcyan', 'lgreen',
           'lightgreen', 'lpurple', 'lightpurple', 'lred', 'lightred','orange',
           'purple', 'que', 'red', 'run','strike', 'under', 'white', 'yellow']

__version__ = '1.1.1'

if __name__ == '__main__':
    print('All commands: ', __all__)
    print('Current version: ', __version__)
